#site_settings.py
#do not edit this file as it may be over-written
#put local customizations in local_settings.
SITE_ID = 116
SITE_DB = 'None'
DEBUG=True
TEMPLATE_DEBUG=True
PRETTYNAME='Jan Walker, Author'
